- Collector for: https://otx.alienvault.com
- Install the library from GitHub, as there is no package in PyPi:
  ```language
  pip install -r REQUIREMENTS.txt
   ```
- The runtime.conf parameter "api_key" has to be set (register on the website to get one)